# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.4.0] - 2021-07-18

- Fixed version declaration
- Update dependencies
- Added `tbump` for version management
- Added `CHANGELOG.md`

## [0.3.0] - 2021-06-21

- Fixed error with required_properties on settings

## [0.2.0] - 2021-06-18

- Fixed Dowload URL on package

## [0.1.0] - 2021-06-18

- Added `migrate` command
- Added `makemigrations` command
